# - Try to find the KDEWIN library
# 
# used environment vars 
#  KDEWIN_DIR  - kdewin root dir 
#  MSSDK_DIR   - ms sdk root dir 
#
# this will define
#  KDEWIN_FOUND - system has KDEWIN
#  KDEWIN_INCLUDES - the KDEWIN include directories
#  KDEWIN_LIBRARIES - The libraries needed to use KDEWIN
#
# Copyright (c) 2006, Alexander Neundorf, <neundorf@kde.org>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.

if (WIN32)
  IF (KDEWIN_INCLUDE_DIR)
    # Already in cache, be silent
    SET(KDEWIN_FIND_QUIETLY TRUE)
  ENDIF (KDEWIN_INCLUDE_DIR)
  
  if (NOT KDEWIN_DIR)
    # check for enviroment variable
    file(TO_CMAKE_PATH "$ENV{KDEWIN_DIR}" KDEWIN_DIR)
    if(NOT KDEWIN_DIR)
      file(TO_CMAKE_PATH "$ENV{PROGRAMFILES}" _progFiles)
      # search in the default program install folder
      if (MSVC)
        set(ext "-msvc")
      else (MSVC)
        set(ext "-mingw")
      endif (MSVC)      
      find_file(KDEWIN_DIR_tmp kdewin${ext} kdewin kdewin32 win32libs
        PATHS
          "${_progFiles}"
      )
      set (KDEWIN_DIR ${KDEWIN_DIR_tmp})
    endif (NOT KDEWIN_DIR)

  endif (NOT KDEWIN_DIR)

  if (KDEWIN_DIR)
    if(NOT QT4_FOUND)
       find_package(Qt4 REQUIRED)
    endif(NOT QT4_FOUND)
  
    find_path(KDEWIN_INCLUDE_DIR winposix_export.h
      ${KDEWIN_DIR}/include 
      ${CMAKE_INSTALL_PREFIX}/include
    )
  
    # find the KDEWIN library, this has to be compiled and installed before kdelibs/
    # search for KDEWIN in the default install directory for applications (default of (n)make install)
  
    find_library(KDEWIN_LIBRARY_RELEASE NAMES kdewin32
      PATHS 
        ${KDEWIN_DIR}/lib
        ${CMAKE_INSTALL_PREFIX}/lib
    )
  
    # msvc makes a difference between debug and release
    if(MSVC)
      find_library(KDEWIN_LIBRARY_DEBUG NAMES KDEWIN32d
        PATHS 
          ${KDEWIN_DIR}/lib
          ${CMAKE_INSTALL_PREFIX}/lib
      )
      if(MSVC_IDE)
        # the ide needs   the debug and release version
        if( NOT KDEWIN_LIBRARY_DEBUG OR NOT KDEWIN_LIBRARY_RELEASE)
           message(FATAL_ERROR "\nCould NOT find the debug AND release version of the KDEWIN library.\nYou need to have both to use MSVC projects.\nPlease build and install both kdelibs/win/ libraries first.\n")
        endif( NOT KDEWIN_LIBRARY_DEBUG OR NOT KDEWIN_LIBRARY_RELEASE)
        SET(KDEWIN_LIBRARY optimized ${KDEWIN_LIBRARY_RELEASE} debug ${KDEWIN_LIBRARY_DEBUG})
      else(MSVC_IDE)
        string(TOLOWER ${CMAKE_BUILD_TYPE} CMAKE_BUILD_TYPE_TOLOWER)
        if(CMAKE_BUILD_TYPE_TOLOWER MATCHES debug)
          set(KDEWIN_LIBRARY ${KDEWIN_LIBRARY_DEBUG})
        else(CMAKE_BUILD_TYPE_TOLOWER MATCHES debug)
          set(KDEWIN_LIBRARY ${KDEWIN_LIBRARY_RELEASE})
        endif(CMAKE_BUILD_TYPE_TOLOWER MATCHES debug)
      endif(MSVC_IDE) 
    else(MSVC)
      set(KDEWIN_LIBRARY ${KDEWIN_LIBRARY_RELEASE})
    endif(MSVC)
  endif (KDEWIN_DIR)
     
  if (KDEWIN_LIBRARY AND KDEWIN_INCLUDE_DIR)
    set(KDEWIN_FOUND TRUE)
    # add needed system libs
    set(KDEWIN_LIBRARIES ${KDEWIN_LIBRARY} user32 shell32 ws2_32)
    if (MINGW)
      #mingw compiler
      set(KDEWIN_INCLUDES ${KDEWIN_INCLUDE_DIR} ${KDEWIN_INCLUDE_DIR}/mingw ${QT_INCLUDES})
    else (MINGW)
      # msvc compiler
      # add the MS SDK include directory if available
      file(TO_CMAKE_PATH "$ENV{MSSDK}" MSSDK_DIR)
      set(KDEWIN_INCLUDES ${KDEWIN_INCLUDE_DIR} ${KDEWIN_INCLUDE_DIR}/msvc  ${QT_INCLUDES} ${MSSDK_DIR})
    endif (MINGW)
     
  endif (KDEWIN_LIBRARY AND KDEWIN_INCLUDE_DIR)
  
  if (KDEWIN_FOUND)
    if (NOT KDEWIN_FIND_QUIETLY)
      message(STATUS "Found KDEWIN: ${KDEWIN_LIBRARY}")
    endif (NOT KDEWIN_FIND_QUIETLY)
  else (KDEWIN_FOUND)
    if (KDEWIN_FIND_REQUIRED)
      message(FATAL_ERROR "Could NOT find KDEWIN library")
    endif (KDEWIN_FIND_REQUIRED)
  endif (KDEWIN_FOUND)
  
  # add include path and library to all targets
  set(CMAKE_INCLUDE_PATH ${CMAKE_INCLUDE_PATH} ${KDEWIN_INCLUDES})
  set(CMAKE_LIBRARY_PATH ${CMAKE_LIBRARY_PATH} ${KDEWIN_DIR}/lib)
  MESSAGE(STATUS ${KDEWIN_INCLUDES})
  
  # required for configure
  set(CMAKE_REQUIRED_INCLUDES ${CMAKE_REQUIRED_INCLUDES} ${KDEWIN_INCLUDES})
  set(CMAKE_REQUIRED_LIBRARIES ${CMAKE_REQUIRED_LIBRARIES} ${KDEWIN_LIBRARIES})      
endif (WIN32)
